package fr.im2ag.m2cci.panier;

/**
 * Représente un article du panier. Un article définit pour un produit donné 
 * la quantité de celui-ci que le client désire acheter.
 *
 * @author Philippe GENOUD - Université Grenoble Alpes (UGA) - Laboratoire
 * Informatique de Grenoble (LIG) - équipe STeamer
 */
public class ArticlePanier {

    /**
     * le produit
     */
    private final Produit produit;
    /**
     * la quantité pour ce produit
     */
    private int quantite;

    public ArticlePanier(Produit p) {
        produit = p;
        quantite = 0;
    }

    //-------------------------------------------------------------------------
    // getters and setters
    //-------------------------------------------------------------------------

    public Produit getProduit() {
        return produit;
    }

    public int getQuantite() {
        return quantite;
    }

    //--------------------------------------------------------------------------
    // autres méthodes
    //--------------------------------------------------------------------------
    /**
     * ajouter pour ce produit une quantité donnée.
     *
     * @param quantite la quantité à ajouter
     */
    void ajouter(int quantite) {
        this.quantite +=  quantite;
    }


    /**
     * retourne le prix hors taxe de cet article
     * @return le prix hors taxe
     */
    public double prixHT() {
        return produit.getPrixUHT() * quantite;
    }

    /**
     * return le prix toutes taxes comprises de cet article
     * @return le prix TTC
     */
    public double prixTTC() {
        return produit.getPrixTTC() * quantite;
    }

    @Override
    public String toString() {
        return produit.toString() + " " + quantite;
    }
}

