package fr.im2ag.m2cci.panier;

/**
 * Représente un produit vendu par le site de commerce électronique.
 * 
 * @author Philippe GENOUD - Université Grenoble Alpes (UGA) - Laboratoire
 * Informatique de Grenoble (LIG) - équipe STeamer
 */
public class Produit {

    /**
     * code du produit
     */
    private final int code;

    /**
     * le nom du produit
     */
    private final String nom;

    /**
     * descripion du produit
     */
    private String description = null;

    /**
     * prix unitaire hors taxe du produit
     */
    private double prixUHT;

    /**
     * taux de TVA (Taxe) en %
     */
    private double tauxTVA;

    /**
     *
     * @param id l'id du produit
     * @param nom le nom du produit
     * @param description la description du produit
     * @param prixUHT le prix unitaire hors taxe du produit
     * @param tva le taux de tva pour le produit
     */
    public Produit(int id, String nom, String description, double prixUHT, double tva) {

        this.code = id;
        this.nom = nom;
        this.description = description;
        this.prixUHT = prixUHT;
        this.tauxTVA = tva;
    }

    /**
     * @return la nom du produit
     */
    public String getNom() {
        return nom;
    }

    /**
     * @return la description du produit
     */
    public String getDescription() {
        return description;
    }


    /**d
     * @return le prix uniatire HT HT (Hors Taxe) du produit
     */
    public double getPrixUHT() {
        return prixUHT;
    }

    /**
     * @return le prix unitaire TTC (Toutes Taxes Comprises) du produit
     */
    public double getPrixTTC() {
        return prixUHT + (prixUHT * tauxTVA) / 100.0;
    }

    /**
     * fixe le prix unitaire hors taxe du produit
     *
     * @param prix le nouveau prix untiate du produit
     */
    public void setPrixUHT(double prix) {
        this.prixUHT = prix;
    }

    /**
     * retourne le code du produit
     *
     * @return code du produit
     */
    public int getCode() {
        return code;
    }

    /**
     * retourne le taux de TVA appliquée à ce produit
     *
     * @return le taux de TVA
     */
    public double getTauxTVA() {
        return tauxTVA;
    }

    /**
     * fixe le taux de TVA appliquée à ce produit
     *
     * @param tauxTVA le taux de TVA
     */
    public void setTauxTVA(double tauxTVA) {
        this.tauxTVA = tauxTVA;
    }

    @Override
    public String toString() {
        return code + " " + description;
    }
}
